#
# spec file for package nasm
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           nasm
Url:            http://nasm.sourceforge.net/
Version:        2.10.09
Release:        6.4
Summary:        Netwide Assembler (An x86 Assembler)
License:        BSD-2-Clause
Group:          Development/Languages/Other
Source:         http://www.nasm.us/pub/nasm/releasebuilds/%{version}/nasm-%{version}.tar.bz2
BuildRequires:  makeinfo
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
NASM is a prototype general-purpose x86 assembler. It can currently
output several binary formats, including ELF, a.out, Win32, and OS/2.

Read the licence agreement in /usr/share/doc/packages/nasm/Licence.

%prep
%setup -q

%package doc
Summary:        Documentation for Nasm
License:        LGPL-2.1+
Group:          Development/Languages/Other
PreReq:         %install_info_prereq
Provides:       nasm:/usr/share/doc/packages/nasm/nasmdoc.pdf

%description doc
This package contains the documentation for Nasm.

%build
touch -r ./ver.c ./ver.c.stamp
TS=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
sed -i "s/__DATE__/\"$TS\"/g" ver.c
touch -r ./ver.c.stamp ./ver.c
%configure
make all

cd doc
make html info nasmdoc.ps nasmdoc.txt

%install
install -d -m 755 $RPM_BUILD_ROOT/usr/bin
install -d -m 755 $RPM_BUILD_ROOT/%{_mandir}/man1
install -d -m 755 $RPM_BUILD_ROOT/%{_docdir}/nasm
install -d -m 755 $RPM_BUILD_ROOT/%{_docdir}/nasm/rdoff
install -d -m 755 $RPM_BUILD_ROOT/%{_docdir}/nasm/html
install -d -m 755 $RPM_BUILD_ROOT/%{_infodir}
make INSTALLROOT=$RPM_BUILD_ROOT install
make INSTALLROOT=$RPM_BUILD_ROOT rdf_install
install -m 644 AUTHORS CHANGES ChangeLog LICENSE TODO README doc/*.txt \
	$RPM_BUILD_ROOT/%{_docdir}/nasm
install -m 644 rdoff/README rdoff/doc/* \
	$RPM_BUILD_ROOT/%{_docdir}/nasm/rdoff
install -m 644 doc/html/* $RPM_BUILD_ROOT%{_docdir}/nasm/html
install -m 644 ndisasm.1 nasm.1 rdoff/*.1 $RPM_BUILD_ROOT%{_mandir}/man1
install -m 644 doc/info/* $RPM_BUILD_ROOT%{_infodir}

%post doc
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun doc
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files
%defattr(-,root,root)
/usr/bin/*
%doc %{_mandir}/man1/*.1.gz

%files doc
%defattr(-,root,root)
%doc %{_docdir}/nasm
%doc %{_infodir}/nasm*

%changelog
* Fri Jul 26 2013 crrodriguez@opensuse.org
- version 2.10.09
  * Add support for the Intel AVX2 instruction set.
  * Add support for Bit Manipulation Instructions 1 and 2.
  * Add support for Intel Transactional Synchronization Extensions (TSX).
  * Add support for x32 ELF
  * Add the ifunc macro package with integer functions,
  currently only integer logarithms.
  * Add support for RDSEED
  * Support of AMD SVM instructions in 32 bit mode
  * Add a bunch of AMD TBM instructions.
  * 2 years of bugfixes
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Sat Sep  8 2012 idonmez@suse.com
- Add explicit build dependency on makeinfo
* Thu Jun 16 2011 per@computer.org
  upgrade to 2.09.08. Lots of changes & fixes since version 2.07:
  C.1.1 Version 2.09.08
  * Fix __OUTPUT_FORMAT__ assignment when output driver alias is used. For example when -f elf
    is used __OUTPUT_FORMAT__ must be set to elf, if -f elf32 is used __OUTPUT_FORMAT__ must be
    assigned accordingly, i.e. to elf32. The rule applies to all output driver aliases. See
    section 4.11.6.
  C.1.2 Version 2.09.07
  * Fix attempts to close same file several times when -a option is used.
  * Fixes for VEXTRACTF128, VMASKMOVPS encoding.
  C.1.3 Version 2.09.06
  * Fix missed section attribute initialization in bin output target.
  C.1.4 Version 2.09.05
  * Fix arguments encoding for VPEXTRW instruction.
  * Remove invalid form of VPEXTRW instruction.
  * Add VLDDQU as alias for VLDQQU to match specification.
  C.1.5 Version 2.09.04
  * Fix incorrect labels offset for VEX intructions.
  * Eliminate bogus warning on implicit operand size override.
  * %%if term could not handle 64 bit numbers.
  * The COFF backend was limiting relocations number to 16 bits even if in real there were a way
    more relocations.
  C.1.6 Version 2.09.03
  * Print %%macro name inside %%rep blocks on error.
  * Fix preprocessor expansion behaviour. It happened sometime too early and sometime simply
    wrong. Move behaviour back to the origins (down to NASM 2.05.01).
  * Fix unitialized data dereference on OMF output format.
  * Issue warning on unterminated %%{ construct.
  * Fix for documentation typo.
  C.1.7 Version 2.09.02
  * Fix reversed tokens when %%deftok produces more than one output token.
  * Fix segmentation fault on disassembling some VEX instructions.
  * Missing %%endif did not always cause error.
  * Fix typo in documentation.
  * Compound context local preprocessor single line macro identifiers were not expanded
    early enough and as result lead to unresolved symbols.
  C.1.8 Version 2.09.01
  * Fix NULL dereference on missed %%deftok second parameter.
  * Fix NULL dereference on invalid %%substr parameters.
  C.1.9 Version 2.09
  * Fixed assignment the magnitude of %%rep counter. It is limited to 62 bits now.
  * Fixed NULL dereference if argument of %%strlen resolves to whitespace. For example if
    nonexistent macro parameter is used.
  * %%ifenv, %%elifenv, %%ifnenv, and %%elifnenv directives introduced. See section 4.4.9.
  * Fixed NULL dereference if environment variable is missed.
  * Updates of new AVX v7 Intel instructions.
  * PUSH imm32 is now officially documented.
  * Fix for encoding the LFS, LGS and LSS in 64-bit mode.
  * Fixes for compatibility with OpenWatcom compiler and DOS 8.3 file format limitation.
  * Macros parameters range expansion introduced. See section 4.3.4.
  * Backward compatibility on expanging of local sigle macros restored.
  * 8 bit relocations for elf and bin output formats are introduced.
  * Short intersegment jumps are permitted now.
  * An alignment more than 64 bytes are allowed for win32, win64 output formats.
  * SECTALIGN directive introduced. See section 4.11.13.
  * nojmp option introduced in smartalign package. See section 5.2.
  * Short aliases win, elf and macho for output formats are introduced. Each stands for
    win32, elf32 and macho32 accordingly.
  * Faster handling of missing directives implemented.
  * Various small improvements in documentation.
  * No hang anymore if unable to open malloc.log file.
  * The environments without vsnprintf function are able to build nasm again.
  * AMD LWP instructions updated.
  * Tighten EA checks. We warn a user if there overflow in EA addressing.
  * Make -Ox the default optimization level. For the legacy behavior, specify -O0 explicitly.
    See section 2.1.22.
  * Environment variables read with %%! or tested with %%ifenv can now contain non-identifier
    characters if surrounded by quotes. See section 4.10.2.
  * Add a new standard macro package %%use fp for floating-point convenience macros. See
    section 5.3.
  C.1.10 Version 2.08.02
  * Fix crash under certain circumstances when using the %%+ operator.
  C.1.11 Version 2.08.01
  * Fix the %%use statement, which was broken in 2.08.
  C.1.12 Version 2.08
  * A number of enhancements/fixes in macros area.
  * Support for converting strings to tokens. See section 4.1.9.
  * Fuzzy operand size logic introduced.
  * Fix COFF stack overrun on too long export identifiers.
  * Fix Macho-O alignment bug.
  * Fix crashes with -fwin32 on file with many exports.
  * Fix stack overrun for too long [DEBUG id].
  * Fix incorrect sbyte usage in IMUL (hit only if optimization flag passed).
  * Append ending token for .stabs records in the ELF output format.
  * New NSIS script which uses ModernUI and MultiUser approach.
  * Visual Studio 2008 NASM integration (rules file).
  * Warn a user if a constant is too long (and as result will be stripped).
  * The obsoleted pre-XOP AMD SSE5 instruction set which was never actualized was removed.
  * Fix stack overrun on too long error file name passed from the command line.
  * Bind symbols to the .text section by default (ie in case if SECTION directive was omitted) in
    the ELF output format.
  * Fix sync points array index wrapping.
  * A few fixes for FMA4 and XOP instruction templates.
  * Add AMD Lightweight Profiling (LWP) instructions.
  * Fix the offset for %%arg in 64-bit mode.
  * An undefined local macro (%%$) no longer matches a global macro with the same name.
  * Fix NULL dereference on too long local labels.
* Fri Dec 17 2010 pgajdos@suse.cz
- don't include pdf in documentation, remove ghostscript from
  build requires to break dependency cycle (jpeg-turbo needs
  nasm for build)
* Mon Aug 30 2010 cristian.rodriguez@opensuse.org
- use __TIMESTAMP__ instead of __DATE__ to make build-compare
  happy.
* Mon Mar  1 2010 ro@suse.de
- update to 2.07
  * NASM is now under the 2-clause BSD license.  See legal.
  * Fix the section type for the .strtab section in the elf64
  output format.
  * Fix the handling of COMMON directives in the obj output format.
  * New ith and srec output formats; these are variants of the
  bin output format which output Intel hex and Motorola S-records,
  respectively.  See ithfmt and srecfmt.
  * rdf2ihx replaced with an enhanced rdf2bin, which can output
  binary, COM, Intel hex or Motorola S-records.
  * The Windows installer now puts the NASM directory first in the
  PATH of the "NASM Shell".
  * Revert the early expansion behavior of %%+ to pre-2.06 behavior:
  %%+ is only expanded late.
  * Yet another Mach-O alignment fix.
  * Don't delete the list file on errors.  Also, include error and
  warning information in the list file.
  * Support for 64-bit Mach-O output, see machofmt.
  * Fix assert failure on certain operations that involve strings with
  high-bit bytes.
* Fri Dec 18 2009 jengelh@medozas.de
- Enable parallel building
* Wed Jan 14 2009 pth@suse.de
- Update to 2.06rc2. Changes since 2.04.rc1:
    2.06:
  * Support for indirect macro expansion ('%%[...]').
  * %%pop' can now take an argument.
  * The argument to %%use' is no longer macro-expanded. Use '%%[...]'
    if macro expansion is desired.
  * Support for thread-local storage in ELF32 and ELF64.
  * Fix crash on '%%ifmacro' without an argument.
  * Correct the arguments to the 'POPCNT' instruction.
    2.05.01:
  * Fix the -w'/-W' option parsing, which was broken in NASM 2.05.
    2.05:
  * Fix redundant REX.W prefix on MP reg64'.
  * Make the behaviour of -O0' match NASM 0.98 legacy behavior.
  * -w-user' can be used to suppress the output of %%warning'
    directives.
  * Fix bug where LIGN' would issue a full alignment datum instead
    of zero bytes.
  * Fix offsets in list files.
  * Fix '%%include' inside multi-line macros or loops.
  * Fix error where NASM would generate a spurious warning on valid
    optimizations of immediate values.
  * Fix arguments to a number of the 'CVT' SSE instructions.
  * Fix RIP-relative offsets when the instruction carries an
    immediate.
  * Massive overhaul of the ELF64 backend for spec compliance.
  * Fix the Geode 'PFRCPV' and 'PFRSQRTV' instruction.
  * Fix the SSE 4.2 'CRC32' instruction.
* Tue Sep  9 2008 pth@suse.de
- Update to 2.04rc1. Changes since 2.03:
  2.04.rc1:
  * Sanitize macro handing in the %%error directive.
  * New %%warning directive to issue user-controlled warnings.
  * __utf16__ and __utf32__ operators to generate UTF-16 and UTF-32
    strings.
  * Correct the handling of nested %%reps.
  * Support for x87 packed BCD constants.
  * New %%strcat directive to join quoted strings together.
  * Correct the LTR instruction in 64-bit mode.
  * Fix unnecessary REX.W prefix on indirect jumps in 64-bit mode.
  * New %%use macro directive to support standard macro directives.
  * Excess default parameters to %%macro now issues a warning by default.
  * Numerous bug fixes, especially to the AES, AVX and VTX instructions.
  2.03.01:
  * Fix buffer overflow in the listing module.
  * Fix the handling of hexadecimal escape codes in `...` strings.
  * The -F option now implies -g.
* Thu Jun 12 2008 pth@suse.de
- Update to 2.03:
  * Add support for Intel AVX, CLMUL and FMA instructions,
    including YMM registers.
  * "dy", "resy" and "yword" for 32-byte operands.
  * Fix some SSE5 instructions.
  * Intel INVEPT, INVVPID and MOVBE instructions.
  * Fix checking for critical expressions when the optimizer is enabled.
  * Support the DWARF debugging format for ELF targets.
  * Fix optimizations of signed bytes.
  * Fix operation on bigendian machines.
  * Fix buffer overflow in the preprocessor.
  * SAFESEH support for Win32, IMAGEREL for Win64 (SEH).
  * %%? and %%?? to refer to the name of a macro itself.  In particular,
    "%%idefine keyword $%%?" can be used to make a keyword "disappear".
  * New options for dependency generation: -MD, -MF, -MP, -MT, -MQ.
  * New preprocessor directives %%pathsearch and %%depend; INCBIN
    reimplemented as a macro.
  * %%include now resolves macros in a sane manner.
  * %%substr can now be used to get other than one-character substrings.
  * New type of character/string constants, using backquotes (`...`),
    which support C-style escape sequences.
  * %%defstr and %%idefstr to stringize macro definitions before creation.
  * Fix forward references used in EQU statements.
- remove nasm-fix-crash.diff as its obsoleted by this version.
* Tue Apr 15 2008 coolo@suse.de
- fix crash in syslinux
* Mon Apr  7 2008 pth@suse.de
- Update to 2.02:
  * Additional fixes for MMX operands with explicit "qword", as well as
    (hopefully) SSE operands with "oword".
  * Fix handling of truncated strings with DO.
  * Fix segfaults due to memory overwrites when floating-point constants
    were used.
  * Fix segfaults due to missing include files.
  * Add autogenerated instruction list back into the documentation.
  * ELF: Fix segfault when generating stabs, and no symbols have been
    defined.
  * ELF: Experimental support for DWARF debugging information.
  * New compile date and time standard macros.
  * %%ifnum now returns true for negative numbers.
  * Add support for the XSAVE instruction group.
  * Fix issue with some warnings getting emitted way too many times.
  * Autogenerated instruction list added to the documentation.
- Split off -doc subpackage
* Tue Jan 22 2008 pth@suse.de
- Update to 2.01 final.
* Thu Jan 10 2008 pth@suse.de
- Update to 2.01rc2:
  2.01
  - ---
  * Fix the handling of MMX registers with explicit "qword" tags on
    memory (broken in 2.00 due to 64-bit changes.)
  * Fix the PREFETCH instructions.
  * Fix the documentation.
  * Fix debugging info when using "-f elf" (backwards alias for "-f
    elf32").
  * Man pages for rdoff tools (from the Debian project.)
  2.00
  - ---
  * Added c99 data-type compliance.
  * Added general x86-64 support.
  * Added win64 (x86-64 COFF) output format.
  * Added __BITS__ standard macro.
  * Renamed the elf output format to elf32 for clarity.
  * Added elf64 and macho (MacOS X) output formats.
  * Added Numeric constants in DQ directive.
  * Added oword, do and reso pseudo operands.
  * Allow underscores in numbers.
  * Added 8-, 16- and 128-bit floating-point formats.
  * Added binary, octal and hexadecimal floating-point.
  * Correct the generation of floating-point constants.
  * Added Floating-point option control.
  * Added Infinity and NaN floating point support.
  * Added ELF Symbol Visibility support.
  * Added Setting OSABI value in ELF header directive.
  * Added Generate Makefile Dependencies option.
  * Added Unlimited Optimization Passes option.
  * Added %%IFN and %%ELIFN support.
  * Added Logical Negation Operator.
  * Enhanced Stack Relative Preprocessor Directives.
  * Enhanced ELF Debug Formats.
  * Enhanced Send Errors to a File option.
  * Added SSSE3, SSE4.1, SSE4.2, SSE5 support.
  * Added a large number of additional instructions.
  * Significant performance improvements.
- Fix array sized to low.
- Fix pointer->int cast.
* Fri Jan 26 2007 ro@suse.de
- replace ghostscript-mini by ghostscript_any in BuildReq (#119914)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Sep 22 2005 uli@suse.de
- update -> 0.98.39 (includes secfix and no longer builds with
  - ansi, among other things)
* Tue Dec 21 2004 sf@suse.de
- use vsnprintf to avoid buffer overflow (#49336)
* Wed Feb 25 2004 stepan@suse.de
- update to 0.98.38
- use -fno-strict-aliasing
- add rdx tools
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Feb 10 2003 mmj@suse.de
- Use %%install_info macro [#23442]
- Use BuildRoot:
* Wed Nov 20 2002 ro@suse.de
- use ghostscript-mini-packages
* Wed Sep 18 2002 uli@suse.de
- update -> 0.98.35 (adds -X option to specify error reporting
  format, drops use of tmpnam() in rdoff)
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Sun Aug 18 2002 ro@suse.de
- fixed neededforbuild
* Sun Aug 18 2002 ro@suse.de
- added ghostscript-x11-packages to neededforbuild (for gs)
* Wed Jul 31 2002 uli@suse.de
- update -> 0.98.34 (need SSE2 support)
- use RPM_OPT_FLAGS
* Thu May  3 2001 uli@suse.de
- schwab fixed the fixed fix, and now it works! No, really, it
  works!
* Wed May  2 2001 uli@suse.de
- ditched the fix, it breaks zsnes 1.20 and God knows what else...
* Fri Apr 27 2001 uli@suse.de
- added a new and improved fix by H.J. Lu...
* Thu Apr 26 2001 uli@suse.de
- some versions of ld don't eat the ELF binaries created by
  nasm 0.98, added fix by H.J. Lu
* Thu Nov  9 2000 uli@suse.de
- added missing docs
* Fri Jun  2 2000 kukuk@suse.de
- Use doc macro
* Thu Mar  2 2000 kukuk@suse.de
- Use _mandir macro
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Jun  4 1999 uli@suse.de
- update -> 0.98
* Thu Dec 17 1998 uli@suse.de
- new package, version 0.97
